@@ -30,6 +30,7 @@ class Gios:
         self.longitude = None
         self.station_name = None
         self._station_data = {}
+        self._available = False
 
         self.session = session
 
@@ -41,6 +42,7 @@ class Gios:
         if not self.station_name:
             stations = await self._get_stations()
             if not stations:
+                self._available = False
                 raise ApiError("Invalid measuring stations list from GIOS API")
 
             for station in stations:
@@ -49,6 +51,7 @@ class Gios:
                     self.longitude = station["gegrLon"]
                     self.station_name = station["stationName"]
             if not self.station_name:
+                self._available = False
                 raise NoStationError(
                     f"{self.station_id} is not a valid measuring station ID"
                 )
@@ -56,7 +59,8 @@ class Gios:
             self._station_data = await self._get_station()
 
         if not self._station_data:
-            raise ApiError("Invalid measuring station data from GIOS API")
+            self._available = False
+            raise InvalidSensorsData("Invalid measuring station data from GIOS API")
 
         for sensor in self._station_data:
             data[sensor["param"]["paramCode"]] = {
@@ -75,11 +79,13 @@ class Gios:
                     elif sensor_data.get("values")[1][ATTR_VALUE]:
                         data[sensor][ATTR_VALUE] = sensor_data["values"][1][ATTR_VALUE]
                     else:
-                        raise ApiError("Invalid sensor data from GIOS API")
+                        self._available = False
+                        raise InvalidSensorsData("Invalid sensor data from GIOS API")
                 else:
                     invalid_sensors.append(sensor)
         except (IndexError, KeyError, TypeError):
-            raise ApiError("Invalid sensor data from GIOS API")
+            self._available = False
+            raise InvalidSensorsData("Invalid sensor data from GIOS API")
 
         if invalid_sensors:
             for sensor in invalid_sensors:
@@ -98,12 +104,9 @@ class Gios:
                 "indexLevelName"
             ].lower()
         except (IndexError, KeyError, TypeError):
-            raise ApiError("Invalid index data from GIOS API")
-
-        # For compatibility with Home Assistant UpdateDataCoordinator
-        data["station_id"] = self.station_id
-        data["station_name"] = self.station_name
-
+            self._available = False
+            raise InvalidSensorsData("Invalid index data from GIOS API")
+        self._available = True
         self.data = data
 
     async def _get_stations(self):
@@ -135,11 +138,17 @@ class Gios:
         async with self.session.get(url) as resp:
             if resp.status != HTTP_OK:
                 _LOGGER.warning("Invalid response from GIOS API: %s", resp.status)
+                self._available = False
                 raise ApiError(resp.status)
             data = await resp.json()
         _LOGGER.debug("Data retrieved from %s, status: %s", url, resp.status)
         return data
 
+    @property
+    def available(self):
+        """Return True is data is available."""
+        return bool(self.data)
+
 
 class ApiError(Exception):
     """Raised when GIOS API request ended in error."""
@@ -150,6 +159,15 @@ class ApiError(Exception):
         self.status = status
 
 
+class InvalidSensorsData(Exception):
+    """Raised when sensors data is invalid."""
+
+    def __init__(self, status):
+        """Initialize."""
+        super(InvalidSensorsData, self).__init__(status)
+        self.status = status
+
+
 class NoStationError(Exception):
     """Raised when no measuring station error."""
 
